tdub.raw_art
------------

A module for producing art from raw information (i.e. not TRExFitter).

.. currentmodule:: tdub.old.raw_art

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   draw_rocs
   draw_stack

Reference
^^^^^^^^^

.. autofunction:: draw_rocs
.. autofunction:: draw_stack
